Crate serde_cadence

Crate serde_cadence 

Modules

impls

Structs

CapabilityValue
CompositeField
CompositeValue
DictionaryEntry
FieldType
FunctionValue
ParameterType
PathValue
RangeValue
TypeValue

Enums

Authorization
CadenceType
Represents a Cadence type in JSON format
CadenceValue
A Cadence value as represented in JSON
Entitlement
Error
Error types for the Cadence-JSON serialization/deserialization
PathDomain

Traits

Deserialize
A data structure that can be deserialized from any data format supported by Serde.
FromCadenceValue
Serialize
A data structure that can be serialized into any data format supported by Serde.
ToCadenceValue

Functions

from_cadence_value
from_reader
Deserializes a Cadence-JSON reader to a Rust type
from_slice
Deserializes a Cadence-JSON byte slice to a Rust type
from_str
Deserializes a Cadence-JSON string to a Rust type
to_cadence_array
Convert a Rust Vec to CadenceValue::Array
to_cadence_bool
Convert a Rust bool to CadenceValue::Bool
to_cadence_dictionary
Convert a Rust Map to CadenceValue::Dictionary
to_cadence_optional
Convert a Rust Option to CadenceValue::Optional
to_cadence_string
Convert a Rust value to CadenceValue::String
to_cadence_value
to_string
Serializes a Rust type to a Cadence-JSON string
to_string_pretty
Serializes a Rust type to a pretty-printed Cadence-JSON string
to_vec
Serializes a Rust type to a Cadence-JSON byte vector
to_vec_pretty
Serializes a Rust type to a pretty-printed Cadence-JSON byte vector

Type Aliases

Result
Result type for Cadence-JSON operations

Derive Macros

Deserialize
FromCadenceValue
Serialize
ToCadenceValue