Modules
Structs
- Capability
Value - Composite
Field - Composite
Value - Dictionary
Entry - Field
Type - Function
Value - Parameter
Type - Path
Value - Range
Value - Type
Value
Enums
- Authorization
- Cadence
Type - Represents a Cadence type in JSON format
- Cadence
Value - A Cadence value as represented in JSON
- Entitlement
- Error
- Error types for the Cadence-JSON serialization/deserialization
- Path
Domain
Traits
- Deserialize
- A data structure that can be deserialized from any data format supported by Serde.
- From
Cadence Value - Serialize
- A data structure that can be serialized into any data format supported by Serde.
- ToCadence
Value
Functions
- from_
cadence_ value - from_
reader - Deserializes a Cadence-JSON reader to a Rust type
- from_
slice - Deserializes a Cadence-JSON byte slice to a Rust type
- from_
str - Deserializes a Cadence-JSON string to a Rust type
- to_
cadence_ array - Convert a Rust Vec to CadenceValue::Array
- to_
cadence_ bool - Convert a Rust bool to CadenceValue::Bool
- to_
cadence_ dictionary - Convert a Rust Map to CadenceValue::Dictionary
- to_
cadence_ optional - Convert a Rust Option to CadenceValue::Optional
- to_
cadence_ string - Convert a Rust value to CadenceValue::String
- to_
cadence_ value - to_
string - Serializes a Rust type to a Cadence-JSON string
- to_
string_ pretty - Serializes a Rust type to a pretty-printed Cadence-JSON string
- to_vec
- Serializes a Rust type to a Cadence-JSON byte vector
- to_
vec_ pretty - Serializes a Rust type to a pretty-printed Cadence-JSON byte vector
Type Aliases
- Result
- Result type for Cadence-JSON operations